#!/bin/sh
#
# bridge       Configures/Dissolves bridges
#
# chkconfig: - 09 91
# description: Activates/Deactivates all ethernet bridges configured to \
#              start at boot time.

# Source function library.
. /etc/init.d/functions

# where to find the brctl tool
BRCTL=/sbin/brctl
BRCFG=/sbin/brcfg

if [ ! -f /etc/sysconfig/network ]; then
    STRING=$"bridge: missing network configuration"
    echo -n "$STRING"
    failure "$STRING"
    echo
    exit 6
fi

. /etc/sysconfig/network

[ -f /etc/sysconfig/pcmcia ] && . /etc/sysconfig/pcmcia


# Check that networking is up.
if [ " ${NETWORKING}" = " no" ] ; then
    STRING=$"bridge: networking disabled"
    echo -n "$STRING"
    failure "$STRING"
    echo
    exit 6
fi

# Check if we want to bridge
if [ " ${BRIDGING}" = " no" ] ; then
    STRING=$"bridge: bridging disabled"
    echo -n "$STRING"
    failure "$STRING"
    echo
    exit 6
fi

# we need the config utilty
if [ ! -x $BRCTL -o ! -x $BRCFG ] ; then
    STRING="bridge: missing configuration program"
    echo -n "$STRING"
    failure "$STRING"
    echo
    exit 5
fi


CWD=`pwd`
cd /etc/sysconfig/network-scripts

# find all the interfaces besides loopback.
# ignore aliases, alternative configurations, and editor backup files
bridges=`ls brcfg* | egrep 'brcfg-[a-z0-9]+$' | \
            sed 's/^brcfg-//g'`
bridges_boot=

for bridge in `ls brcfg* | egrep 'brcfg-[a-z0-9]+$'`; do
      br=`egrep -L "ONBOOT=\"?[Nn][Oo]\"?" $bridge | sed 's/^brcfg-//g'`
      [ -n "$br" ] && bridges_boot="$bridges_boot $br"
done

# list active bridges
list_bridges () {
    local br=""
    br=`$BRCTL show         | \
        tail +2             | \
        grep "^[a-zA-Z0-9]" | \
        sed -e "s/^\([a-zA-Z0-9]*\).*/\1/"`
    echo $br
}

# start bridging (create bridges)
start () {
    local b

    # load bridge module
    modprobe bridge || true

    for b in $bridges_boot; do
        action "Configurating bridge $b:" $BRCFG $b boot
    done
}

# stop bridging (disassembly bridges)
stop () {
    local b rc
    
    for b in `list_bridges`; do
        action "Shutting down bridge $b:" $BRCTL delbr $b
    done
}


rc=0

# See how we were called.
case "$1" in
    start)
        start
    ;;
    stop)
        stop
    ;;
    status)
        echo -n "Configured bridges: "
        echo $bridges

        echo -n "Currently active bridges: "
        echo `list_bridges`
    ;;
    restart)
        stop
        start
	;;
    *)
        echo "Usage: bridge {start|stop|restart|status}"
        rc=3
    ;;
esac

cd $CWD

exit $rc
